===============================
``psyclone.psyir.nodes.clause``
===============================

.. automodule:: psyclone.psyir.nodes.clause

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.clause
